@@ -3,7 +3,7 @@
 
 /*
 
-  Copyright 2012-2019 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -34,9 +34,7 @@ enum class output_polygon_type {
 /**
  * This class encapsulates the command line parsing.
  */
-class Options {
-
-public:
+struct Options {
 
     /// Input OSM file name.
     std::string inputfile;
@@ -59,6 +57,9 @@ public:
     /// Show debug output?
     bool debug = false;
 
+    /// GDAL driver.
+    std::string driver = "SQLite";
+
     /// Maximum number of points in polygons.
     int max_points_in_polygon = 1000;
 
@@ -68,7 +69,7 @@ public:
     /// What polygons should be written out?
     output_polygon_type output_polygons = output_polygon_type::land;
 
-    /// Output Spatialite database file name.
+    /// Output database file name.
     std::string output_database;
 
     /// Should output database be overwritten
@@ -97,17 +98,6 @@ public:
 
     Options(int argc, char* argv[]);
 
-private:
-
-    /**
-     * Get EPSG code from text. This method knows about a few common cases
-     * of specifying WGS84 or the "Web Mercator" SRS. More are currently
-     * not supported.
-     */
-    int get_epsg(const char* text);
-
-    void print_help() const;
-
-}; // class Options
+}; // struct Options
 
 #endif // OPTIONS_HPP
